[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[elpa] externals/standard-themes c35a9cff44 5/7: Add standard-light-tint
From: |
ELPA Syncer |
Subject: |
[elpa] externals/standard-themes c35a9cff44 5/7: Add standard-light-tinted and standard-dark-tinted themes |
Date: |
Tue, 17 Dec 2024 04:03:25 -0500 (EST) |
branch: externals/standard-themes
commit c35a9cff44ea487719dc14065ae521ab63a56faa
Author: Protesilaos Stavrou <info@protesilaos.com>
Commit: Protesilaos Stavrou <info@protesilaos.com>
Add standard-light-tinted and standard-dark-tinted themes
---
README.md | 12 ++-
README.org | 12 ++-
standard-dark-theme.el | 10 +-
...-dark-theme.el => standard-dark-tinted-theme.el | 104 ++++++++++----------
standard-light-theme.el | 10 +-
...ight-theme.el => standard-light-tinted-theme.el | 108 +++++++++++----------
standard-themes.el | 16 ++-
7 files changed, 147 insertions(+), 125 deletions(-)
diff --git a/README.md b/README.md
index 82877b4036..5748cfde03 100644
--- a/README.md
+++ b/README.md
@@ -1,9 +1,13 @@
# Standard themes for GNU Emacs
-The `standard-themes` are a pair of light and dark themes for GNU
-Emacs. They emulate the out-of-the-box looks of Emacs (which
-technically do NOT constitute a theme) while bringing to them thematic
-consistency, customizability, and extensibility.
+The `standard-themes` are a collection of light and dark themes for
+GNU Emacs. The `standard-light` and `standard-dark` emulate the
+out-of-the-box looks of Emacs (which technically do NOT constitute a
+theme) while bringing to them thematic consistency, customizability,
+and extensibility. Other themes are stylistic variations of those.
+
+Why call them "standard"? Obviously because: Standard Themes Are Not
+Derivatives but the Affectionately Reimagined Default ... themes.
+ Package name (GNU ELPA): `standard-themes`
+ Official manual: <https://protesilaos.com/emacs/standard-themes>
diff --git a/README.org b/README.org
index 0f8edb071c..5889658682 100644
--- a/README.org
+++ b/README.org
@@ -70,10 +70,14 @@ modify this GNU manual.”
:CUSTOM_ID: h:fd5bf657-937d-4e42-b936-b423ef4f45ee
:END:
-The ~standard-themes~ are a pair of light and dark themes for GNU
-Emacs. They emulate the out-of-the-box looks of Emacs (which
-technically do NOT constitute a theme) while bringing to them thematic
-consistency, customizability, and extensibility.
+The ~standard-themes~ are a collection of light and dark themes for
+GNU Emacs. The ~standard-light~ and ~standard-dark~ emulate the
+out-of-the-box looks of Emacs (which technically do NOT constitute a
+theme) while bringing to them thematic consistency, customizability,
+and extensibility. Other themes are stylistic variations of those.
+
+Why call them "standard"? Obviously because: Standard Themes Are Not
+Derivatives but the Affectionately Reimagined Default ... themes.
* Installation
:PROPERTIES:
diff --git a/standard-dark-theme.el b/standard-dark-theme.el
index 192ad43602..ed8ac9cb04 100644
--- a/standard-dark-theme.el
+++ b/standard-dark-theme.el
@@ -24,10 +24,12 @@
;;; Commentary:
;;
-;; The `standard-themes' are a pair of light and dark themes for GNU
-;; Emacs. They emulate the out-of-the-box looks of Emacs (which
-;; technically do NOT constitute a theme) while bringing to them
-;; thematic consistency, customizability, and extensibility.
+;; The `standard-themes' are a collection of light and dark themes for
+;; GNU Emacs. The `standard-light' and `standard-dark' emulate the
+;; out-of-the-box looks of Emacs (which technically do NOT constitute
+;; a theme) while bringing to them thematic consistency,
+;; customizability, and extensibility. Other themes are stylistic
+;; variations of those.
;;
;; Why call them "standard"? Obviously because: Standard Themes Are
;; Not Derivatives but the Affectionately Reimagined Default ... themes.
diff --git a/standard-dark-theme.el b/standard-dark-tinted-theme.el
similarity index 78%
copy from standard-dark-theme.el
copy to standard-dark-tinted-theme.el
index 192ad43602..a6fef78b69 100644
--- a/standard-dark-theme.el
+++ b/standard-dark-tinted-theme.el
@@ -1,4 +1,4 @@
-;;; standard-dark-theme.el --- Like the unthemed dark Emacs, but more
consistent -*- lexical-binding:t -*-
+;;; standard-dark-tinted-theme.el --- More nightly variant of standard-dark
theme -*- lexical-binding:t -*-
;; Copyright (C) 2022-2024 Free Software Foundation, Inc.
@@ -24,10 +24,12 @@
;;; Commentary:
;;
-;; The `standard-themes' are a pair of light and dark themes for GNU
-;; Emacs. They emulate the out-of-the-box looks of Emacs (which
-;; technically do NOT constitute a theme) while bringing to them
-;; thematic consistency, customizability, and extensibility.
+;; The `standard-themes' are a collection of light and dark themes for
+;; GNU Emacs. The `standard-light' and `standard-dark' emulate the
+;; out-of-the-box looks of Emacs (which technically do NOT constitute
+;; a theme) while bringing to them thematic consistency,
+;; customizability, and extensibility. Other themes are stylistic
+;; variations of those.
;;
;; Why call them "standard"? Obviously because: Standard Themes Are
;; Not Derivatives but the Affectionately Reimagined Default ... themes.
@@ -40,25 +42,25 @@
(require 'standard-themes)
;;;###theme-autoload
- (deftheme standard-dark
- "Like the unthemed dark Emacs, but more consistent."
+ (deftheme standard-dark-tinted
+ "More nightly variant of standard-dark theme."
:background-mode 'dark
:kind 'color-scheme
:family 'standard)
- (defconst standard-dark-palette
+ (defconst standard-dark-tinted-palette
'(
;;; Basic values
- (bg-main "#000000")
+ (bg-main "#182440")
(fg-main "#ffffff")
- (bg-dim "#202020")
+ (bg-dim "#2e3355")
(fg-dim "#a6a6a6")
- (bg-alt "#363636")
+ (bg-alt "#3f4560")
(fg-alt "#a0afef")
- (bg-active "#606060")
- (bg-inactive "#141414")
- (border "#606070")
+ (bg-active "#5f6580")
+ (bg-inactive "#252844")
+ (border "#707090")
;; Basic accent foregrounds
@@ -112,30 +114,30 @@
;;; Diffs
- (bg-added "#00331f")
- (bg-added-faint "#002410")
- (bg-added-refine "#03492f")
+ (bg-added "#12522f")
+ (bg-added-faint "#0f3a30")
+ (bg-added-refine "#13694f")
(fg-added "#4fb04f")
- (bg-changed "#323200")
- (bg-changed-faint "#281a00")
- (bg-changed-refine "#484800")
+ (bg-changed "#424200")
+ (bg-changed-faint "#383a00")
+ (bg-changed-refine "#684f20")
(fg-changed "#e0cf03")
- (bg-removed "#4a1119")
- (bg-removed-faint "#320a0f")
- (bg-removed-refine "#751a1f")
+ (bg-removed "#602119")
+ (bg-removed-faint "#4e0f1f")
+ (bg-removed-refine "#792f2f")
(fg-removed "#ff5f5f")
;;; Marks
- (bg-mark-alt "#002f4a")
- (fg-mark-alt "#57cefa")
+ (bg-mark-alt "#223f6a")
+ (fg-mark-alt "#57defa")
- (bg-mark-del "#440d09")
- (fg-mark-del "#ff5f60")
+ (bg-mark-del "#5a201f")
+ (fg-mark-del "#ff7f60")
- (bg-mark-sel "#333000")
+ (bg-mark-sel "#494000")
(fg-mark-sel "#d0d082")
;;; Graphs
@@ -156,27 +158,27 @@
;;; Special hues
(bg-accent "#ffc200")
- (bg-completion "#254b5f")
- (bg-hover "#457b2f")
+ (bg-completion "#406a70")
+ (bg-hover "#35705f")
(bg-hover-alt "#00688b")
- (bg-hl-line "#334815")
- (bg-region "#20009d")
+ (bg-hl-line "#304845")
+ (bg-region "#4f2f99")
(fg-region unspecified)
(bg-paren "#4f94cd")
- (bg-err "#3f0d09") ; check with err
- (bg-warning "#362f00") ; check with warning
- (bg-info "#002f12") ; check with info
+ (bg-err "#5f1f1f") ; check with err
+ (bg-warning "#434100") ; check with warning
+ (bg-info "#20481f") ; check with info
- (bg-mode-line-active "#505050")
+ (bg-mode-line-active "#5b59b2")
(fg-mode-line-active "#ffffff")
- (border-mode-line-active "#959595")
- (bg-mode-line-inactive "#323232")
+ (border-mode-line-active "#9595b5")
+ (bg-mode-line-inactive "#353a52")
(fg-mode-line-inactive "#a6a6a6")
(border-mode-line-inactive "#606070")
- (bg-tab "#333333")
- (bg-tab-inactive "#4d4d4d")
- (bg-tab-inactive-alt "#666666")
+ (bg-tab "#374073")
+ (bg-tab-inactive "#545f90")
+ (bg-tab-inactive-alt "#6a7898")
(modeline-err "#ff80af")
(modeline-warning "#dfcf33")
@@ -190,7 +192,7 @@
;;;; General mappings
- (cursor fg-main)
+ (cursor "#d072f0")
(fringe bg-dim)
(name cyan-cooler)
(keybind blue-cooler)
@@ -214,7 +216,7 @@
;;;; Prompt mappings
(bg-prompt unspecified)
- (fg-prompt blue)
+ (fg-prompt cyan)
;;;; Code mappings
@@ -321,7 +323,7 @@
(overline-heading-6 unspecified)
(overline-heading-7 unspecified)
(overline-heading-8 unspecified))
- "The `standard-dark' palette.
+ "The `standard-dark-tinted' palette.
Color values have the form (COLOR-NAME HEX-VALUE) with the former
as a symbol and the latter as a string.
@@ -329,8 +331,8 @@ Semantic color mappings have the form (MAPPING-NAME
COLOR-NAME)
with both as symbols. The latter is a color that already exists
in the palette and is associated with a HEX-VALUE.")
- (defcustom standard-dark-palette-overrides nil
- "Overrides for `standard-dark-palette'.
+ (defcustom standard-dark-tinted-palette-overrides nil
+ "Overrides for `standard-dark-tinted-palette'.
Mirror the elements of the aforementioned palette, overriding
their value.
@@ -349,10 +351,10 @@ represents."
:type '(repeat (list symbol (choice symbol string)))
:link '(info-link "(standard-themes) Palette overrides"))
- (standard-themes-theme standard-dark
- standard-dark-palette
- standard-dark-palette-overrides)
+ (standard-themes-theme standard-dark-tinted
+ standard-dark-tinted-palette
+ standard-dark-tinted-palette-overrides)
- (provide-theme 'standard-dark))
+ (provide-theme 'standard-dark-tinted))
-;;; standard-dark-theme.el ends here
+;;; standard-dark-tinted-theme.el ends here
diff --git a/standard-light-theme.el b/standard-light-theme.el
index 79f753574b..628c00e706 100644
--- a/standard-light-theme.el
+++ b/standard-light-theme.el
@@ -24,10 +24,12 @@
;;; Commentary:
;;
-;; The `standard-themes' are a pair of light and dark themes for GNU
-;; Emacs. They emulate the out-of-the-box looks of Emacs (which
-;; technically do NOT constitute a theme) while bringing to them
-;; thematic consistency, customizability, and extensibility.
+;; The `standard-themes' are a collection of light and dark themes for
+;; GNU Emacs. The `standard-light' and `standard-dark' emulate the
+;; out-of-the-box looks of Emacs (which technically do NOT constitute
+;; a theme) while bringing to them thematic consistency,
+;; customizability, and extensibility. Other themes are stylistic
+;; variations of those.
;;
;; Why call them "standard"? Obviously because: Standard Themes Are
;; Not Derivatives but the Affectionately Reimagined Default ... themes.
diff --git a/standard-light-theme.el b/standard-light-tinted-theme.el
similarity index 77%
copy from standard-light-theme.el
copy to standard-light-tinted-theme.el
index 79f753574b..9f61bacb8e 100644
--- a/standard-light-theme.el
+++ b/standard-light-tinted-theme.el
@@ -1,4 +1,4 @@
-;;; standard-light-theme.el --- Like the unthemed light Emacs, but more
consistent -*- lexical-binding:t -*-
+;;; standard-light-tinted-theme.el --- More earthly variant of standard-light
theme -*- lexical-binding:t -*-
;; Copyright (C) 2022-2024 Free Software Foundation, Inc.
@@ -24,10 +24,12 @@
;;; Commentary:
;;
-;; The `standard-themes' are a pair of light and dark themes for GNU
-;; Emacs. They emulate the out-of-the-box looks of Emacs (which
-;; technically do NOT constitute a theme) while bringing to them
-;; thematic consistency, customizability, and extensibility.
+;; The `standard-themes' are a collection of light and dark themes for
+;; GNU Emacs. The `standard-light' and `standard-dark' emulate the
+;; out-of-the-box looks of Emacs (which technically do NOT constitute
+;; a theme) while bringing to them thematic consistency,
+;; customizability, and extensibility. Other themes are stylistic
+;; variations of those.
;;
;; Why call them "standard"? Obviously because: Standard Themes Are
;; Not Derivatives but the Affectionately Reimagined Default ... themes.
@@ -40,25 +42,25 @@
(require 'standard-themes)
;;;###theme-autoload
- (deftheme standard-light
- "Like the unthemed light Emacs, but more consistent."
+ (deftheme standard-light-tinted
+ "More earthly variant of standard-light theme."
:background-mode 'light
:kind 'color-scheme
:family 'standard)
- (defconst standard-light-palette
+ (defconst standard-light-tinted-palette
'(
;;; Basic values
- (bg-main "#ffffff")
+ (bg-main "#eeecd9")
(fg-main "#000000")
- (bg-dim "#ededed")
- (fg-dim "#7f7f7f")
- (bg-alt "#dcdcdc")
+ (bg-dim "#e2d3ca")
+ (fg-dim "#606060")
+ (bg-alt "#d0bab0")
(fg-alt "#193f8f")
- (bg-active "#bfbfbf")
- (bg-inactive "#f5f5f5")
- (border "#bababa")
+ (bg-active "#b09a90")
+ (bg-inactive "#e0e0d0")
+ (border "#9a7a7a")
;;; Basic accent foregrounds
@@ -112,20 +114,20 @@
;;; Diffs
- (bg-added "#c0f8d0")
- (bg-added-faint "#d0ffe0")
- (bg-added-refine "#b4e8c4")
- (fg-added "#007200")
+ (bg-added "#c3ebc1")
+ (bg-added-faint "#d0eac0")
+ (bg-added-refine "#acd6a5")
+ (fg-added "#005000")
- (bg-changed "#ffdfa9")
- (bg-changed-faint "#ffefbf")
- (bg-changed-refine "#fac090")
- (fg-changed "#8d6a12")
+ (bg-changed "#ffdfa9")
+ (bg-changed-faint "#ffe2bf")
+ (bg-changed-refine "#fac090")
+ (fg-changed "#553d00")
- (bg-removed "#ffd8d5")
- (bg-removed-faint "#ffe9e9")
- (bg-removed-refine "#f3b5af")
- (fg-removed "#a02a2a")
+ (bg-removed "#f4c2c7")
+ (bg-removed-faint "#f2d3d0")
+ (bg-removed-refine "#f3b5a7")
+ (fg-removed "#8f1313")
;;; Marks
@@ -156,27 +158,27 @@
;;; Special hues
(bg-accent "#0000cc")
- (bg-completion "#bfe8ff")
- (bg-hover "#aaeccf")
+ (bg-completion "#afc8df")
+ (bg-hover "#8acf9f")
(bg-hover-alt "#ffff00")
- (bg-hl-line "#b4eeb4")
- (bg-region "#eedc82")
+ (bg-hl-line "#b6ded0")
+ (bg-region "#d0acb2")
(fg-region unspecified)
- (bg-paren "#40e0d0")
- (bg-err "#ffd5ea") ; check with err
- (bg-warning "#ffeabb") ; check with warning
- (bg-info "#d0efda") ; check with info
+ (bg-paren "#40aff0")
+ (bg-err "#f0c8cf") ; check with err
+ (bg-warning "#f0ea8b") ; check with warning
+ (bg-info "#b0d3ef") ; check with info
- (bg-mode-line-active "#b3b3b3")
+ (bg-mode-line-active "#cf93a0")
(fg-mode-line-active "#000000")
- (border-mode-line-active "#5a5a5a")
- (bg-mode-line-inactive "#e5e5e5")
- (fg-mode-line-inactive "#7f7f7f")
- (border-mode-line-inactive "#bababa")
+ (border-mode-line-active "#7a5a50")
+ (bg-mode-line-inactive "#d0baaf")
+ (fg-mode-line-inactive "#503f3f")
+ (border-mode-line-inactive "#b39590")
- (bg-tab "#d9d9d9")
- (bg-tab-inactive "#bfbfbf")
- (bg-tab-inactive-alt "#a6a6a6")
+ (bg-tab "#d9c9ba")
+ (bg-tab-inactive "#b6a89f")
+ (bg-tab-inactive-alt "#af9486")
(modeline-err "#b02020")
(modeline-warning "#5f1080")
@@ -190,7 +192,7 @@
;;;; General mappings
- (cursor fg-main)
+ (cursor "#aa0090")
(fringe bg-dim)
(name green-cooler)
(keybind blue)
@@ -214,7 +216,7 @@
;;;; Prompt mappings
(bg-prompt unspecified)
- (fg-prompt blue-cooler)
+ (fg-prompt magenta)
;;;; Code mappings
@@ -321,7 +323,7 @@
(overline-heading-6 unspecified)
(overline-heading-7 unspecified)
(overline-heading-8 unspecified))
- "The `standard-light' palette.
+ "The `standard-light-tinted' palette.
Color values have the form (COLOR-NAME HEX-VALUE) with the former
as a symbol and the latter as a string.
@@ -329,8 +331,8 @@ Semantic color mappings have the form (MAPPING-NAME
COLOR-NAME)
with both as symbols. The latter is a color that already exists
in the palette and is associated with a HEX-VALUE.")
- (defcustom standard-light-palette-overrides nil
- "Overrides for `standard-light-palette'.
+ (defcustom standard-light-tinted-palette-overrides nil
+ "Overrides for `standard-light-tinted-palette'.
Mirror the elements of the aforementioned palette, overriding
their value.
@@ -349,10 +351,10 @@ represents."
:type '(repeat (list symbol (choice symbol string)))
:link '(info-link "(standard-themes) Palette overrides"))
- (standard-themes-theme standard-light
- standard-light-palette
- standard-light-palette-overrides)
+ (standard-themes-theme standard-light-tinted
+ standard-light-tinted-palette
+ standard-light-tinted-palette-overrides)
- (provide-theme 'standard-light))
+ (provide-theme 'standard-light-tinted))
-;;; standard-light-theme.el ends here
+;;; standard-light-tinted-theme.el ends here
diff --git a/standard-themes.el b/standard-themes.el
index f2c4418aae..0f352a1eb2 100644
--- a/standard-themes.el
+++ b/standard-themes.el
@@ -26,10 +26,12 @@
;;; Commentary:
;;
;; The `standard-themes' are a pair of light and dark themes for GNU
;; Emacs. They emulate the out-of-the-box looks of Emacs (which
;; technically do NOT constitute a theme) while bringing to them
;; thematic consistency, customizability, and extensibility.
;;
;; Why call them "standard"? Obviously because: Standard Themes Are
;; Not Derivatives but the Affectionately Reimagined Default ... themes.
@@ -49,7 +51,11 @@
;;; User options
-(defconst standard-themes-items '(standard-dark standard-light)
+(defvaralias 'standard-themes-collection 'standard-themes-items
+ "Alias of `standard-themes-items'.")
+
+(defconst standard-themes-items
+ '(standard-light standard-light-tinted standard-dark standard-dark-tinted)
"Symbols of the Standard themes.")
(defcustom standard-themes-disable-other-themes t
- [elpa] externals/standard-themes updated (226e7b95b1 -> 03babcff5c), ELPA Syncer, 2024/12/17
- [elpa] externals/standard-themes 3f3d3bb6a1 4/7: Define alias for standard-themes-post-load-hook, ELPA Syncer, 2024/12/17
- [elpa] externals/standard-themes 7c5234a964 1/7: Make Emacs 28 the minimum required version, ELPA Syncer, 2024/12/17
- [elpa] externals/standard-themes 64450a350d 6/7: Define commands and concomitant options to toggle and rotate between Standard themes, ELPA Syncer, 2024/12/17
- [elpa] externals/standard-themes bb9ff4e19a 3/7: Add support for pulsar package, ELPA Syncer, 2024/12/17
- [elpa] externals/standard-themes c35a9cff44 5/7: Add standard-light-tinted and standard-dark-tinted themes,
ELPA Syncer <=
- [elpa] externals/standard-themes 03babcff5c 7/7: Refactor the preview palette mechanism to use tabulated-list-mode, ELPA Syncer, 2024/12/17
- [elpa] externals/standard-themes 9e9043fe26 2/7: Add support for lin package, ELPA Syncer, 2024/12/17
@@ -26,10 +26,12 @@
;;; Commentary:
;;
-;; The `standard-themes' are a pair of light and dark themes for GNU
-;; Emacs. They emulate the out-of-the-box looks of Emacs (which
-;; technically do NOT constitute a theme) while bringing to them
-;; thematic consistency, customizability, and extensibility.
+;; The `standard-themes' are a collection of light and dark themes for
+;; GNU Emacs. The `standard-light' and `standard-dark' emulate the
+;; out-of-the-box looks of Emacs (which technically do NOT constitute
+;; a theme) while bringing to them thematic consistency,
+;; customizability, and extensibility. Other themes are stylistic
+;; variations of those.
;;
;; Why call them "standard"? Obviously because: Standard Themes Are